Dnsimple.Certificate (dnsimple v3.1.0) View Source
Represents an SSL certificate.
The server, root and chain attributes are only relevant for the
download endpoint accessible through Dnsimple.Certificates.download_certificate/5.
The private_key attribute is only relevant for the private key endpoint
accessible through Dnsimple.Certificates.get_certificate_private_key/5.
See:
Link to this section Summary
Link to this section Types
Specs
t() :: %Dnsimple.Certificate{
alternate_names: List.t(),
authority_identifier: String.t(),
auto_renew: boolean(),
chain: String.t(),
common_name: String.t(),
contact_id: integer(),
created_at: String.t(),
csr: String.t(),
domain_id: integer(),
expires_at: String.t(),
id: integer(),
private_key: String.t(),
root: String.t(),
server: String.t(),
state: String.t(),
updated_at: String.t(),
years: integer()
}