dnsimple v0.9.2 Dnsimple.TldExtendedAttribute.Option
Represents one of the accepted values for an extended attribute of a TLD.
See: https://developer.dnsimple.com/v2/tlds/#extended-attributes
Represents one of the accepted values for an extended attribute of a TLD.
See: https://developer.dnsimple.com/v2/tlds/#extended-attributes