dnsimple v0.9.2 Dnsimple.Tlds

This module provides functions to interact with the TLD related endpoints.

See: https://developer.dnsimple.com/v2/tlds/

Summary

Functions

Returns the information about a TLD

Returns the extended attributes required for a particular TLD

Returns the lists of supported TLDs on DNSimple

See Dnsimple.Tlds.get_tld/2

See Dnsimple.Tlds.get_tld_extended_attributes/2

See Dnsimple.Tlds.list_tlds/1

Functions

get_tld(client, tld, options \\ [])

Returns the information about a TLD.

See https://developer.dnsimple.com/v2/tlds/#get

Examples

client = %Dnsimple.Client{access_token: “a1b2c3d4”}

Dnsimple.Tlds.get_tld(client, “com”)

get_tld_extended_attributes(client, tld, options \\ [])

Specs

get_tld_extended_attributes(Dnsimple.Client.t, String.t, Keyword.t) :: Dnsimple.Response.t

Returns the extended attributes required for a particular TLD.

See https://developer.dnsimple.com/v2/tlds/#extended-attributes

Examples

# client = %Dnsimple.Client{access_token: “a1b2c3d4”}

Dnsimple.Tlds.get_tld_extended_attributes(client, “com”)

list_tlds(client, options \\ [])

Returns the lists of supported TLDs on DNSimple.

See https://developer.dnsimple.com/v2/tlds/#list

Examples

client = %Dnsimple.Client{access_token: “a1b2c3d4”}

Dnsimple.Tlds.list_tlds(client) Dnsimple.Tlds.list_tlds(client, page: 2, per_page: 10) Dnsimple.Tlds.list_tlds(client, sort: “tlds:desc”)

tld(client, tld)

See Dnsimple.Tlds.get_tld/2.

tld(client, tld, options)

See Dnsimple.Tlds.get_tld/3.

tld_extended_attributes(client, tld)

See Dnsimple.Tlds.get_tld_extended_attributes/2.

tld_extended_attributes(client, tld, options)

Specs

See Dnsimple.Tlds.get_tld_extended_attributes/3.

tlds(client)

See Dnsimple.Tlds.list_tlds/1.