dnsimple v0.9.2 Dnsimple.VanityNameServers

This module provides functions to interact with the vanity name server related endpoints.

See: https://developer.dnsimple.com/v2/vanity/

Summary

Functions

Enables and returns vanity name servers for the domain

Functions

disable_vanity_name_servers(client, account_id, domain_id, options \\ [])

Specs

disable_vanity_name_servers(Dnsimple.Client.t, String.t | integer, String.t | integer, Keyword.t) :: Dnsimple.Response.t

Disables vanity name servers for the domain.

See https://developer.dnsimple.com/v2/vanity/#disable

Examples:

client = %Dnsimple.Client{access_token: “a1b2c3d4”}

Dnsimple.VanityNameServers.disable_vanity_name_servers(client, account_id = 1010, domain_id = “example.com”)

enable_vanity_name_servers(client, account_id, domain_id, options \\ [])

Specs

enable_vanity_name_servers(Dnsimple.Client.t, String.t | integer, String.t | integer, Keyword.t) :: Dnsimple.Response.t

Enables and returns vanity name servers for the domain.

See https://developer.dnsimple.com/v2/vanity/#enable

Examples:

client = %Dnsimple.Client{access_token: “a1b2c3d4”}

Dnsimple.VanityNameServers.enable_vanity_name_servers(client, account_id = 1010, domain_id = “example.com”)