dnsimple v0.9.2 Dnsimple.Registrar
This module provides functions to interact with the registrar related endpoints.
See: https://developer.dnsimple.com/v2/registrar/ See: https://developer.dnsimple.com/v2/registrar/auto-renewal/ See: https://developer.dnsimple.com/v2/registrar/whois-privacy/ See: https://developer.dnsimple.com/v2/registrar/delegation/
Summary
Functions
Changes the domain’s name servers and returns them
Reverts all the operations performed to delegate to vanity name servers and delegates the domain back to DNSimple’s name servers (if DNSimple is the registrar of the domain)
Changes the domain’s name servers to a set of vanity name servers and returns them
Checks whether a domain is available to be registered
Disables auto-renewal for the domain
Disables whois privacy for the domain
See Dnsimple.Registrar.get_domain_delegation/3
Enables auto-renewal for the domain
Enables whois privacy for the domain
Returns the name servers the domain is delegating to
Returns the whois privacy of the domain
Registers a domain
Starts the transfer of a domain to DNSimple
Requests the transfer of a domain out of DNSimple
See Dnsimple.Registrar.get_whois_privacy/3
Functions
Specs
change_domain_delegation(Dnsimple.Client.t, integer | String.t, String.t, List.t, Keyword.t) :: Dnsimple.Response.t
Changes the domain’s name servers and returns them.
See: https://developer.dnsimple.com/v2/registrar/delegation/#update
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.change_domain_delegation(client, account_id = 1010, domain_id = “example.com”, [
"ns1.provider.com",
"ns2.provider.com",
"ns3.provider.com",
"ns4.provider.com",
])
Specs
change_domain_delegation_from_vanity(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Reverts all the operations performed to delegate to vanity name servers and delegates the domain back to DNSimple’s name servers (if DNSimple is the registrar of the domain).
See: https://developer.dnsimple.com/v2/registrar/delegation/#dedelegateFromVanity
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.change_domain_delegation_from_vanity(client, account_id = 1010, domain_id = “example.com”)
Specs
change_domain_delegation_to_vanity(Dnsimple.Client.t, integer | String.t, String.t, List.t, Keyword.t) :: Dnsimple.Response.t
Changes the domain’s name servers to a set of vanity name servers and returns them.
See: https://developer.dnsimple.com/v2/registrar/delegation/#delegateToVanity
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.change_domain_delegation_to_vanity(client, account_id = 1010, domain_id = “example.com”, [
"ns1.example.com.com",
"ns2.example.com.com",
"ns3.example.com.com",
"ns4.example.com.com",
])
Specs
check_domain(Dnsimple.Client.t, String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Checks whether a domain is available to be registered.
See: https://developer.dnsimple.com/v2/registrar/#check
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.check_domain(client, account_id = 1010, domain_id = “example.com”)
Specs
disable_domain_auto_renewal(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Disables auto-renewal for the domain.
See: https://developer.dnsimple.com/v2/registrar/auto-renewal/#disable
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.disable_domain_auto_renewal(client, account_id = 1010, domain_id = “example.com”)
Specs
disable_whois_privacy(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Disables whois privacy for the domain.
See: https://developer.dnsimple.com/v2/registrar/whois-privacy/#disable
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.disable_whois_privacy(client, account_id = 1010, domain_id = “example.com”)
Specs
domain_delegation(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Specs
enable_domain_auto_renewal(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Enables auto-renewal for the domain.
See: https://developer.dnsimple.com/v2/registrar/auto-renewal/#enable
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.enable_domain_auto_renewal(client, account_id = 1010, domain_id = “example.com”)
Specs
enable_whois_privacy(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Enables whois privacy for the domain.
See: https://developer.dnsimple.com/v2/registrar/whois-privacy/#enable
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.enable_whois_privacy(client, account_id = 1010, domain_id = “example.com”)
Specs
get_domain_delegation(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Returns the name servers the domain is delegating to.
See: https://developer.dnsimple.com/v2/registrar/delegation/#list
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.get_domain_delegation(client, account_id = 1010, domain_id = “example.com”)
Specs
get_whois_privacy(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Returns the whois privacy of the domain.
See: https://developer.dnsimple.com/v2/registrar/whois-privacy/#get
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.get_whois_privacy(client, account_id = 1010, domain_id = “example.com”)
Specs
register_domain(Dnsimple.Client.t, String.t, String.t, Keyword.t, Keyword.t) :: Dnsimple.Response.t
Registers a domain.
See https://developer.dnsimple.com/v2/registrar/#register
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.register_domain(client, account_id = 1010, domain_id = “example.com”, %{
registrant_id: 1,
privacy: true,
auto_renew: false,
})
Specs
renew_domain(Dnsimple.Client.t, String.t, String.t, Keyword.t, Keyword.t) :: Dnsimple.Response.t
Renews a domain.
See https://developer.dnsimple.com/v2/registrar/#renew
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.renew_domain(client, account_id = 1010, domain_id = “example.com”) Dnsimple.Registrar.renew_domain(client, account_id = 1010, domain_id = “example.com”, %{period: 5})
Specs
transfer_domain(Dnsimple.Client.t, String.t, String.t, Keyword.t, Keyword.t) :: Dnsimple.Response.t
Starts the transfer of a domain to DNSimple.
See https://developer.dnsimple.com/v2/registrar/#transfer
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.transfer_domain(client, account_id = 1010, domain_id = “example.com”, %{
registrant_id: 1,
auth_code: "XXXXXXXXX",
privacy: true,
auto_renew: true,
})
Specs
transfer_domain_out(Dnsimple.Client.t, String.t, String.t, Keyword.t) :: Dnsimple.Response.t
Requests the transfer of a domain out of DNSimple.
See https://developer.dnsimple.com/v2/registrar/#transfer_out
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Registrar.transfer_domain_out(client, account_id = 1010, domain_id = “example.com”)
Specs
whois_privacy(Dnsimple.Client.t, integer | String.t, String.t, Keyword.t) :: Dnsimple.Response.t