dnsimple v0.9.2 Dnsimple.Tlds
This module provides functions to interact with the TLD related endpoints.
Summary
Functions
Returns the information about a TLD
Returns the extended attributes required for a particular TLD
Returns the lists of supported TLDs on DNSimple
See Dnsimple.Tlds.get_tld/2
See Dnsimple.Tlds.get_tld_extended_attributes/2
See Dnsimple.Tlds.list_tlds/1
Functions
Specs
get_tld(Dnsimple.Client.t, String.t, Keyword.t) :: Dnsimple.Response.t
Returns the information about a TLD.
See https://developer.dnsimple.com/v2/tlds/#get
Examples
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Tlds.get_tld(client, “com”)
Specs
get_tld_extended_attributes(Dnsimple.Client.t, String.t, Keyword.t) :: Dnsimple.Response.t
Returns the extended attributes required for a particular TLD.
See https://developer.dnsimple.com/v2/tlds/#extended-attributes
Examples
# client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Tlds.get_tld_extended_attributes(client, “com”)
Specs
list_tlds(Dnsimple.Client.t, Keyword.t) :: Dnsimple.Response.t
Returns the lists of supported TLDs on DNSimple.
See https://developer.dnsimple.com/v2/tlds/#list
Examples
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.Tlds.list_tlds(client) Dnsimple.Tlds.list_tlds(client, page: 2, per_page: 10) Dnsimple.Tlds.list_tlds(client, sort: “tlds:desc”)
Specs
Specs
tld_extended_attributes(Dnsimple.Client.t, String.t, Keyword.t) :: Dnsimple.Response.t
Specs
tlds(Dnsimple.Client.t, Keyword.t) :: Dnsimple.Response.t