dnsimple v0.9.2 Dnsimple.VanityNameServers
This module provides functions to interact with the vanity name server related endpoints.
Summary
Functions
Disables vanity name servers for the domain
Enables and returns vanity name servers for the domain
Functions
Specs
disable_vanity_name_servers(Dnsimple.Client.t, String.t | integer, String.t | integer, Keyword.t) :: Dnsimple.Response.t
Disables vanity name servers for the domain.
See https://developer.dnsimple.com/v2/vanity/#disable
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.VanityNameServers.disable_vanity_name_servers(client, account_id = 1010, domain_id = “example.com”)
Specs
enable_vanity_name_servers(Dnsimple.Client.t, String.t | integer, String.t | integer, Keyword.t) :: Dnsimple.Response.t
Enables and returns vanity name servers for the domain.
See https://developer.dnsimple.com/v2/vanity/#enable
Examples:
client = %Dnsimple.Client{access_token: “a1b2c3d4”}
Dnsimple.VanityNameServers.enable_vanity_name_servers(client, account_id = 1010, domain_id = “example.com”)