Contributing to DNSimple/Elixir
View SourceGetting started
Clone the repository and move into it:
git clone git@github.com:dnsimple/dnsimple-elixir.git
cd dnsimple-elixir
Install Elixir and the dependencies:
mix deps.get
Compile the project and run the test suite to check everything works as expected.
Changelog
We follow the Common Changelog format for changelog entries.
Testing
Run the test suite:
mix test
Submit unit tests for your changes. You can test your changes on your machine by running the test suite.
When you submit a PR, tests will also be run on the continuous integration environment via GitHub Actions.